"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../shared/constants");
const aws_commands_1 = require("./util/aws-commands");
const lodash_1 = __importDefault(require("lodash"));
const filterProjects_1 = require("./util/filterProjects");
const selectProject_1 = require("./util/selectProject");
const executeCommands_1 = require("./util/executeCommands");
const logger_1 = __importDefault(require("../../../shared/logger"));
const chalk_1 = __importDefault(require("chalk"));
const ora_1 = __importDefault(require("ora"));
const required_credentials_1 = require("../../credentials/required-credentials");
let state = {
    path: '',
    criteria: '',
    credentials: {
        username: '',
        pwd: ''
    },
    projectList: {
        repositories: []
    }
};
exports.default = (crit, branch, all) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        // 0. Set path and branch
        state.path = process.cwd() + '/';
        branch ? branch = `-b ${branch}` : branch = constants_1.configuration.git.command_default_branch_clone;
        logger_1.default.debug(`Branch to use ${branch}`);
        const spinner = ora_1.default('Start cloning process').start();
        spinner.stop();
        // 1. Obtengo las credenciales del usuario
        let credentials;
        credentials = yield required_credentials_1.PrompCredentials();
        if (!lodash_1.default.isEmpty(credentials)) {
            // Set the credentials
            state.credentials = credentials;
            // 2. Obtengo el criterio de busqueda para los projectos
            let criteria = '';
            if (crit) {
                spinner.start();
                spinner.text = `Search proyects with ${chalk_1.default.redBright(crit)} \n`;
                criteria = crit;
                logger_1.default.debug(`Use the indicate criteria for clone filter the projects list  ${chalk_1.default.whiteBright('criteria')}: ${chalk_1.default.redBright(crit)}`);
            }
            else {
                spinner.fail('Error on clone \n');
                // criteria = await getCriteriaOfSearch();
                logger_1.default.error('Your no indicate the criteria for search the project list.');
                process.exit();
            }
            if (criteria) {
                // set the current criteria for search
                state.criteria = criteria;
                // 3. Obtengo la lista de projectos de aws
                state.projectList = yield aws_commands_1.getProjectDirectory();
                if (state.projectList.repositories.length > 0) {
                    let filterProject = [];
                    filterProject = state.projectList.repositories;
                    // 3.1 Filtro el array de acuerdo al criterio de busqueda, si se indica all como criterio paso a obtener todos los projectos
                    if (criteria != 'all') {
                        filterProject = yield filterProjects_1.filterProjects(state.projectList, state.criteria);
                    }
                    // 3.2 Agrego la opción para realizar el filtro de dependencias por parte del usuario
                    filterProject.map((item) => {
                        item.title = `${item.repositoryName}`;
                        item.value = `${item.repositoryName}`;
                        item.repositoryId = `${item.repositoryId}`;
                        item.selected = true;
                    });
                    let selectProject = filterProject;
                    // 3.3 Valido si el usuario indico el clonar todos los projectos automaticamente, si no se ha indicado esto. paso a mostrar el seleccionable del prompt
                    if (!all) {
                        spinner.stop();
                        // 3.3.1 Seleciono los projecto a clonar
                        selectProject = yield selectProject_1.findDependency(filterProject);
                    }
                    if (selectProject) {
                        spinner.text = '';
                        spinner.start();
                        // 4. Obtengo la información de los repositorios de aws. para poder realizar la clonación
                        let results = selectProject.map((element) => __awaiter(void 0, void 0, void 0, function* () {
                            let metadata = yield aws_commands_1.getProjectInformation(element.repositoryName);
                            element.repositoryMetadata = metadata.repositoryMetadata;
                        }));
                        // 4.1 Espero a que finalicen todas los await definidos en el map
                        Promise.all(results).then(() => __awaiter(void 0, void 0, void 0, function* () {
                            // 5 Realizo el proceso de clonación
                            let options = {
                                path: state.path,
                                credentials: state.credentials,
                                projectList: selectProject,
                                branch: branch,
                                position: 0
                            };
                            let cloned = yield executeCommands_1.executeCommands(options);
                            cloned == true
                                ? spinner.succeed('Proyect clone succes')
                                : spinner.fail('Process clone succes with errors');
                        }));
                    }
                    else {
                        logger_1.default.warn('No projects found');
                    }
                }
                else {
                    logger_1.default.warn('No project select to clone');
                }
            }
            else {
                logger_1.default.warn('No have criteria for search projects');
            }
        }
    }
    catch (e) {
        logger_1.default.debug(e);
    }
});
