"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../../shared/constants");
const child_process_1 = require("child_process");
const logger_1 = __importDefault(require("../../../../shared/logger"));
/**
 *  Método para obtener la lista de repositorios disponibles en aws
 */
exports.getProjectDirectory = () => {
    return new Promise(function (fulfill, reject) {
        try {
            let result;
            child_process_1.exec(constants_1.configuration.aws.command_list_repositories, (error, stdout, _stderr) => {
                if (error) {
                    logger_1.default.error("AWS Error:" + error);
                    logger_1.default.info(constants_1.configuration.messages.awsAccesKey);
                    reject(error);
                    process.exit(1);
                }
                result = JSON.parse(stdout.toString());
                fulfill(result);
            });
        }
        catch (error) {
            logger_1.default.debug(error);
            reject(error);
        }
    });
};
exports.getProjectInformation = (projectName) => {
    return new Promise(function (fulfill, reject) {
        try {
            let result;
            child_process_1.exec(`${constants_1.configuration.aws.command_get_repositories} ${projectName}`, (error, stdout, _stderr) => {
                if (error) {
                    logger_1.default.info(constants_1.configuration.messages.awsAccesKey);
                    reject(error);
                    process.exit(1);
                }
                result = JSON.parse(stdout.toString());
                fulfill(result);
            });
        }
        catch (error) {
            logger_1.default.debug(error);
            reject(error);
        }
    });
};
exports.cloneProject = (options) => {
    return new Promise(function (fulfill, reject) {
        try {
            logger_1.default.info(`Cloning ${options.project.repositoryMetadata.cloneUrlHttp}`);
            const repositorie = options.project.repositoryMetadata.cloneUrlHttp.replace("https://", "");
            const task = child_process_1.spawn(`cd ${options.path} && ${constants_1.configuration.git.command_clone} https://${options.credentials.username}:${options.credentials.pwd}@${repositorie} ${options.branch} `, [], { shell: true });
            task.on("close", () => {
                fulfill(true);
            });
            // Método para imprimir el log normal
            task.stdout.on("data", data => {
                logger_1.default.info(data.toString());
            });
            // Método para imprimir el log de error
            task.stderr.on("data", (data) => {
                logger_1.default.info(data.toString());
                if (data.toString().includes("already exists and is not an empty directory")) {
                    fulfill(false);
                }
            });
        }
        catch (error) {
            logger_1.default.debug(error);
            reject(error);
            process.exit(1);
        }
    });
};
