"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const shared_1 = require("./../../../shared");
const get_template_1 = require("./util/get-template");
const dirname = process.cwd();
const { codeCommitTriggerDir } = shared_1.configuration.code_commit;
let fs = require("fs");
/**
 * Este archivo realiza la creación de la estructura base para el tema de la aplicación.
 * recibe como parametro el nombre del tema que se va a emplear
 *
 */
exports.default = (destinationArn) => __awaiter(void 0, void 0, void 0, function* () {
    shared_1.logger.info("Creating aws triggers configuration");
    // Generación de la configuración de branch y schema
    const branch = yield shared_1.readFileInDirectory(`${dirname}/trigger-config.json`, true);
    if (!branch) {
        process.exit(1);
    }
    // 1. Leo el directorio actual y permito seleccionar todos los proyectos deseados
    const currentDirectory = yield shared_1.readDirectoryByFiles(dirname, ["manifest.json"], "Pick the projects to use", "Select the projects");
    // 2. Obtengo los nombres de los proyectos. en base al nombre de la carpeta
    let repositoryNames = getProjectNames(currentDirectory);
    // 2. Armo el objeto que contendra los recursos de codecommit y codebuild. ademas de la información basica para el codepipeline
    repositoryNames.map(nameProject => {
        const config = {
            codeCommitProject: nameProject,
            branches: branch,
            destinationArn: destinationArn,
            updateReference: ["updateReference"]
        };
        // change the url to clone with the current name
        let copy = JSON.stringify(config.branches);
        copy = JSON.parse(copy);
        copy.map((item) => {
            item.customData.urlToClone += `/${nameProject}`;
            item.customData.linkCommand = item.customData.linkCommand.replace(/\s+/g, "@S");
            item.customData.publishCommand = item.customData.publishCommand.replace(/\s+/g, "@S");
            item.customData.linkCommand = item.customData.linkCommand.replace(/\&&+/g, "@AND");
            item.customData.publishCommand = item.customData.publishCommand.replace(/\&&+/g, "@AND");
        });
        config.branches = copy;
        createAwsTemplate(config);
    });
});
// Método que recorre la lista de proyectos y obtiene el nombre a emplear de acuerdo a la carpeta.
const getProjectNames = (currentDirectory) => {
    let repositoryNames = [];
    currentDirectory.map((item) => __awaiter(void 0, void 0, void 0, function* () {
        repositoryNames.push(shared_1.getRepositoryName(item));
    }));
    return repositoryNames;
};
const createAwsTemplate = (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield ensureDirectoryExistence(dirname);
    yield ensureDirectoryExistence(dirname + `/${codeCommitTriggerDir}`);
    yield createTemplate(config);
});
const ensureDirectoryExistence = (filePath) => __awaiter(void 0, void 0, void 0, function* () {
    if (fs.existsSync(filePath)) {
        return true;
    }
    yield fs.mkdirSync(filePath);
    return true;
});
/**
 * Método que sobreescribe el archivo de tema base para la aplicación.
 */
const createTemplate = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const template = yield get_template_1.getTemplateContent(options);
    return fs.writeFile(`${dirname}/${codeCommitTriggerDir}/${options.codeCommitProject}.json`, template, function (err) {
        if (err) {
            throw err;
        }
    });
});
