"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const lodash_1 = __importDefault(require("lodash"));
const shared_1 = require("../../../shared");
const overwrite_changelog_1 = require("./util/overwrite-changelog");
const directory = process.cwd();
function default_1(criteria) {
    return __awaiter(this, void 0, void 0, function* () {
        shared_1.logger.info("OverWrite dependencies", directory);
        if (!criteria) {
            shared_1.logger.error("Not pass the criteria to use");
            process.exit(1);
        }
        // 1. Obtengo el cotenido del archivo de configuración con las dependencias a actualizar
        const configDependencies = yield shared_1.readFileInDirectory(`${directory}/update-dependencies.json`, false);
        if (!configDependencies) {
            process.exit(1);
        }
        // 2. Obtengo la lista de proyectos a emplear, busco los proyectos en el directorio actual.
        const projectsInCurrentDirectory = yield shared_1.readDirectoryByFiles(directory, ["manifest.json"], "Pick the projects to use", "Select the projects");
        // 3. Paso a obtener el contenido de los archivo seleccionados
        let manifestContent = yield findProjectContent(projectsInCurrentDirectory);
        if (!manifestContent.length) {
            shared_1.logger.error("No manifest content");
            process.exit(1);
        }
        // Filtro los proyectos con dependencias vacias
        let filterElements = manifestContent.filter((item) => Object.getOwnPropertyNames(item.dependencies).length > 0);
        shared_1.logger.warn(`Found projects with empty dependencies, only use ${filterElements.length} projects to update dependencies`);
        // Recorro los projectos y realizo la actualización de las dependencias. valido si se realizaron los cambios en alguna de las dependencias y preparo el array final para realizar la actualización de los archivos manifest.json
        let manifestUpdate = filterElements.filter((item) => {
            let dependencies = lodash_1.default.pick(JSON.parse(configDependencies), Object.keys(item.dependencies).filter(item => item.startsWith(criteria)));
            // EL Objecto `dependencies` posee la lista de dependencias a actualizar. este es un objecto con las versiones a emplear
            if (isEmpty(dependencies)) {
                shared_1.logger.info(`No have dependencies in the file update-dependencies.json with the criteria indicate ${criteria}`);
                shared_1.logger.warn(`${configDependencies}`);
                shared_1.logger.info("Check the .json file and try again");
            }
            // Si las dependencias actuales son diferentes a las que se preparan para modificar
            if (!isEmpty(dependencies) &&
                !objectEquals(item.dependencies, dependencies, criteria)) {
                // Lógica que permite capturar la ultima versión en base a la versión actual que posee el proyecto.
                // Hay dependencias que pueden tener mas de una versión, ejem "vtex.render-server": "8.47.2-7.39.0"
                // Lo que se hace es obtener un array en base a las versiones disponibles de una versión [8.47.2,7.39.0]
                // Si se indica que se emplee la ultima versión siempre con la variable lastVersion, se pasa a emplear la ultima versión que sería 8.47.2
                // Si no se indica que se emplee la ultima versión, se pasa a realizar una busqueda de la ultima versión en base a la versión actual
                // [8.47.2,7.39.0]  de la versión actual que es 8.x. con lo que trae la versión 8.47.2, si se indica la versión 7.x se trae la ultima versión pero de 7.39.0
                let dependenciesToUse = {};
                // Variable que arma un objeto en base a las keys filstradas por el cricterio, arma el objeto con key y value, para así obtener la lista de depencias a emplear
                const filterDependencies = Object.keys(item.dependencies)
                    .filter((key) => key.startsWith(criteria))
                    .reduce((obj, key) => {
                    obj[key] = item.dependencies[key];
                    return obj;
                }, {});
                // Variable que contiene la lista de dependencias final a emplear, esto ya que puedo realizar el filtro del objeto filterDependencies y remover keys que no van a ser necesarias para emplear.
                let filterDependenciesToUse = filterDependencies;
                Object.keys(dependencies).map((itemDependencies, index) => {
                    // Variable que contiene la lista de versiones a emplear de la dependencia
                    let listVersion = Object.values(dependencies)[index].split('-');
                    let versionToUse = listVersion[0];
                    // Capturo el flag para saber si empleo la ultima versión siempre o no.
                    const LASTVERSION = '--last';
                    const lastVersion = process.argv.indexOf(LASTVERSION) >= 0;
                    // Si no se indica que se use la ultima versión y el número de versiones es mayor o igual a 2
                    if (!lastVersion && listVersion.length >= 2) {
                        versionToUse = listVersion.find((val) => val.startsWith(Object.values(filterDependencies)[index].split('.')[0]));
                        if (!versionToUse) {
                            // Remuevo la dependencia que no se encontro de acuerdo a la versión empleada actualmente, esto permite validar si la dependnecia actual existe pero la version solicitada no existe.
                            filterDependenciesToUse = lodash_1.default.omit(filterDependencies, itemDependencies);
                        }
                    }
                    if (versionToUse) {
                        dependenciesToUse = Object.assign(Object.assign({}, dependenciesToUse), { [itemDependencies]: versionToUse });
                    }
                    return item;
                });
                // Si la lista de depenencias con la versión validada se encuentra null, paso a mostrar mensaje indicando que no hay versiones a emplear
                if (!isEmpty(dependenciesToUse) && !objectEquals(filterDependenciesToUse, dependenciesToUse, criteria)) {
                    let tempItem = {
                        dependencies: dependenciesToUse,
                        version: newVersion(item.version),
                    };
                    // Paso a crear una variable que contiene la versión y la lista de depencias
                    tempItem.changelog = {
                        version: tempItem.version,
                        dependencies: dependenciesToUse
                    };
                    item = lodash_1.default.merge(item, tempItem);
                    return item;
                }
                else {
                    shared_1.logger.warn(`The dependencies from the project ${item.vendor +
                        "." +
                        item.name} is already update`);
                }
            }
            else {
                shared_1.logger.warn(`The dependencies from the project ${item.vendor +
                    "." +
                    item.name} is already update`);
            }
        });
        if (manifestUpdate.length) {
            manifestUpdate.map((item) => __awaiter(this, void 0, void 0, function* () {
                // Realizo la escritura del archivo ChangeLog agregando las dependencias modificadas y el número de la versión
                yield overwrite_changelog_1.overWriteChangeLogFile(item.path, item.changelog);
                // Escribo el archivo manifest.json
                yield writeFile(item.path, JSON.stringify(removeData(item), null, 4));
            }));
        }
        else {
            shared_1.logger.info("No have projects to update, all projects already are update");
        }
    });
}
exports.default = default_1;
// Método que remueve el path del objecto
const removeData = (item) => {
    delete item.path;
    delete item.changelog;
    return item;
};
function isEmpty(obj) {
    return !obj || Object.keys(obj).length === 0;
}
// Método que valida dos arrays para saber si son iguales
function arraysEqual(arr1, arr2) {
    if (arr1.length !== arr2.length)
        return false;
    for (var i = arr1.length; i--;) {
        if (arr1[i].key === arr2[i].key && arr1[i].value !== arr2[i].value)
            return false;
    }
    return true;
}
// Método que permite armar un array con key y values, para poder validar si tanto la key como el value son iguales
function objectEquals(objec1, object2, criteria) {
    var output1 = Object.entries(objec1)
        .map(([key, value]) => ({ key, value }))
        .filter(item => item.key.startsWith(criteria));
    var output2 = Object.entries(object2)
        .map(([key, value]) => ({ key, value }))
        .filter(item => item.key.startsWith(criteria));
    return arraysEqual(output1, output2);
}
// Método que genera un cambio en la version pasada
const newVersion = (currentVersion) => {
    const items = currentVersion.split(".");
    items[1] = String(Number(items[1]) + 1);
    items[2] = String(Number(0));
    return items.join(".");
};
const findProjectContent = (files) => __awaiter(void 0, void 0, void 0, function* () {
    // si hay directorios, paso a buscar el archivo manifest.json y obtener su contenido
    const manifests = yield shared_1.getManifestsContent(files);
    if (manifests.length) {
        return manifests;
    }
    else {
        return [];
    }
});
// Método para escribir el archivo manifest.json
const writeFile = (path, string) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_1.writeFileSync(path + "/manifest.json", string);
        shared_1.logger.debug(`manifest file update in the directory ${path}`);
    }
    catch (error) {
        shared_1.logger.error(error);
    }
});
