"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const chalk_1 = __importDefault(require("chalk"));
const ora_1 = __importDefault(require("ora"));
const shared_1 = require("./../../../../shared");
const save_credentials_1 = require("./util/save-credentials");
// Call to get auth information
const getAuth = (workspace, account, token) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const url = `https://${workspace}--${account}.myvtex.com/exito/token?credentials=${token}?config=${makeId()}`;
        shared_1.logger.debug(url);
        return yield axios_1.default.get(url);
    }
    catch (error) {
        shared_1.logger.debug(error);
        shared_1.logger.error("Error on get auth token");
        process.exit(1);
    }
});
function makeId() {
    var text = "";
    var possible = "abcdefghijklmnopqrstuvwxyz";
    for (var i = 0; i < 5; i++)
        text += possible.charAt(Math.floor(Math.random() * possible.length));
    return text;
}
function default_1(account, workspace, email, token, path) {
    return __awaiter(this, void 0, void 0, function* () {
        const spinner = ora_1.default("Getting auth token \n").start();
        spinner.stop();
        const auth = yield getAuth(workspace, account, token);
        spinner.start();
        if (auth) {
            const authToken = auth.data;
            // print information
            spinner.succeed(`auth token to use: ${chalk_1.default.redBright(authToken.slice(1, 20))}...`);
            shared_1.logger.info(`Credentials for use ${chalk_1.default.redBright(account)} as ${chalk_1.default.redBright(email)} at workspace ${chalk_1.default.redBright(workspace)}`);
            // options for the file config.json
            const options = {
                account: account,
                token: authToken,
                workspace: workspace,
                login: email,
                env: "prod"
            };
            // 1. Overrite the config file from vtex
            yield save_credentials_1.saveVtexConfig(options, path);
            spinner.succeed(`Now you logged in Vtex!!`);
        }
        else {
            spinner.fail("No token information found.");
            process.exit(1);
        }
    });
}
exports.default = default_1;
