"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const shared_1 = require("../../../../shared");
// variable que indica donde se encuentan los archivos a emplear
let directory = "";
// variable que posee el comando que se va a ejecutar actualmente
let commands = "";
// variable que posee la lista de dependencias ordenadas por nivel
let dependenciesList = [];
// variable que posee la información  de los manifest.json
let manifests = [];
// variable que indica si se debe organizar el orden de las dependencias de mayor relevancia a menor
let orderList = false;
// 1. Método inicial que se encarga de buscar las carpetas dentro del directorio indicado.
exports.default = (command, all) => __awaiter(void 0, void 0, void 0, function* () {
    // indico cual comando se va a ejecutar y cual directorio se va a emplear
    directory = process.cwd() + "/";
    orderList = true;
    // Capturo el flag para saber si empleo la ultima versión siempre o no.
    const SCAPECOMMAND = "--scape";
    const scapeCommand = process.argv.indexOf(SCAPECOMMAND) >= 0;
    commands = command;
    if (scapeCommand) {
        commands = command.replace(/\@S+/g, " ");
        commands = commands.replace(/\@AND+/g, "&&");
    }
    shared_1.logger.debug(`Order dependencies list ${orderList}`);
    shared_1.logger.debug(`Command to run: ${commands}`);
    shared_1.logger.debug(`Directory to use: ${directory}`);
    if (command && directory) {
        // Realizo la busqueda en el directorio actual
        exports.searchProjectCurrentDirectory(all);
    }
    else {
        shared_1.logger.error(`No commands specified to run`);
    }
});
// Método que se encarga de buscar un proyecto en el directorio actual
exports.searchProjectCurrentDirectory = (all) => __awaiter(void 0, void 0, void 0, function* () {
    shared_1.logger.debug("Use the current location for search one project");
    let response = yield exports.findProjectContent([directory], all);
    // si no se encontraron projectos en el directorio actual, paso a buscar en los sub directorios.
    if (!response) {
        // obtengo todos los nombres de las carpetas dentro del directorio indicado
        let files = yield shared_1.getDirectories(directory);
        if (files.length) {
            let subFiles = yield exports.findProjectContent(files, all);
            if (!subFiles) {
                process.exit(1);
            }
        }
        else {
            shared_1.logger.warn(`No projects found in ${directory}`);
            process.exit(1);
        }
    }
});
exports.findProjectContent = (files, all) => __awaiter(void 0, void 0, void 0, function* () {
    // si hay directorios, paso a buscar el archivo manifest.json y obtener su contenido
    manifests = yield shared_1.getManifestsContent(files);
    // Obtengo el orden en que se van a compilar las dependencias
    dependenciesList = yield shared_1.getListProjects(manifests);
    // Luego de finalizar la busqueda de dependencias, paso a ejecutar los comandos por medio de consola
    if (dependenciesList.length) {
        // cambio el orden a asc, esto permitira ejecutar primero los componentes que son dependencias
        if (orderList) {
            dependenciesList.reverse();
        }
        // busco la dependencia en el manifest y paso toda su información de manifest
        shared_1.logger.info(`You have ${chalk_1.default.redBright(`${dependenciesList.length}`)} proyects to link`);
        let dependenciesToUse = dependenciesList;
        if (!all) {
            dependenciesToUse = yield shared_1.findDependency(dependenciesList);
        }
        if (dependenciesToUse.length) {
            let options = {
                position: 0,
                manifests: manifests,
                dependenciesList: dependenciesToUse,
                commands: commands
            };
            shared_1.executeCommands(options);
        }
        return true;
    }
    else {
        shared_1.logger.debug(`No dependencies found in the current location`);
        return false;
    }
});
