"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importStar(require("fs"));
const shared_1 = require("../../../shared");
const get_jest_config_content_1 = require("./util/get-jest-config-content");
const directory = process.cwd() + "/";
function default_1() {
    return __awaiter(this, void 0, void 0, function* () {
        shared_1.logger.info("Run coverage");
        //1. Busco en el directorio actual si existen proyectos con el archivo manifest.json
        let response = yield findProject([directory]);
        // si no se encontraron projectos en el directorio actual, paso a buscar en los sub directorios.
        if (!response) {
            // obtengo todos los nombres de las carpetas dentro del directorio indicado
            let files = yield shared_1.getDirectories(directory);
            if (files.length) {
                let subFiles = yield findProject(files);
                if (!subFiles) {
                    process.exit(1);
                }
                else {
                    shared_1.logger.info(`Project found in the sub location`);
                }
            }
            else {
                shared_1.logger.warn(`No projects found in ${directory}`);
                process.exit(1);
            }
        }
    });
}
exports.default = default_1;
//2. Tomo el directorio encontrado y paso a buscar la carpeta node o react
const findProject = (files) => __awaiter(void 0, void 0, void 0, function* () {
    // si hay directorios, paso a buscar el archivo manifest.json y obtener su contenido
    shared_1.logger.debug(`Searching projects in ${files}`);
    const manifests = yield shared_1.getManifestsContent(files);
    if (manifests.length) {
        shared_1.logger.info(`Projects found in the folder: ${files}`);
        manifests.map((item) => {
            findNodeOrReactFolder(item.path);
        });
        return true;
    }
    else {
        return false;
    }
});
//3. De acuerdo al directorio encontrado, paso a realizar la instalación de las dependencias
const findNodeOrReactFolder = (file) => __awaiter(void 0, void 0, void 0, function* () {
    if (fs_1.default.existsSync(file + "/node") == true) {
        shared_1.logger.info("Project contain the folder node");
        const command = `cd ${file}/node && node ./node_modules/jest/bin/jest.js --coverage -u && cd ../..`;
        yield addPercentageOfCoverage(`${file}/node/jest.config.js`);
        yield addLoginDataSonarQube(`${file}/node/sonar-project.properties`);
        // Ejecuto el proceso de coverage
        shared_1.runMultipleCommand(command, [
            `Jest: "global" coverage threshold for`,
            "test failed in"
        ]);
    }
    else if (fs_1.default.existsSync(file + "/react") == true) {
        shared_1.logger.info("Project contain the folder react");
        const command = `cd ${file}/react && node ./node_modules/jest/bin/jest.js --coverage -u && ./node_modules/sonar-scanner/bin/sonar-scanner && cd ../..`;
        yield addPercentageOfCoverage(`${file}/react/jest.config.js`);
        yield addLoginDataSonarQube(`${file}/react/sonar-project.properties`);
        // Ejecuto el proceso de coverage
        shared_1.runMultipleCommand(command, [
            `Jest: "global" coverage threshold for`,
            "Permission denied",
            "test failed in"
        ]);
    }
});
const writeFileLocal = (path, string) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_1.writeFileSync(path, string, "utf8");
        return true;
    }
    catch (error) {
        shared_1.logger.error(error);
        process.exit(1);
    }
});
//4. Logica que busca el archivo jest.config.js y agrega la configuración de cobertura minima
const addPercentageOfCoverage = (dir) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const jest = yield get_jest_config_content_1.getJestConfigContent(dir);
        yield writeFileLocal(dir, jest);
        return true;
    }
    catch (error) {
        shared_1.logger.error(error);
    }
});
//4. Logica que busca el archivo jest.config.js y agrega la configuración de cobertura minima
const addLoginDataSonarQube = (dir) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const sonar = yield get_jest_config_content_1.getSonarQubeContent(dir);
        yield writeFileLocal(dir, sonar);
        return true;
    }
    catch (error) {
        shared_1.logger.error(error);
    }
});
