"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const shared_1 = require("./../../../shared");
const directory = process.cwd();
function default_1(vendor) {
    return __awaiter(this, void 0, void 0, function* () {
        //1. Busco en el directorio actual si existen proyectos con el archivo manifest.json
        let response = yield findProjectContent([directory], vendor);
        // si no se encontraron projectos en el directorio actual, paso a buscar en los sub directorios.
        if (!response) {
            // obtengo todos los nombres de las carpetas dentro del directorio indicado
            let files = yield shared_1.getDirectories(directory);
            if (files.length) {
                let subFiles = yield findProjectContent(files, vendor);
                if (!subFiles) {
                    process.exit(1);
                }
            }
            else {
                shared_1.logger.warn(`No projects found in ${directory}`);
                process.exit(1);
            }
        }
    });
}
exports.default = default_1;
const findProjectContent = (files, vendor) => __awaiter(void 0, void 0, void 0, function* () {
    // si hay directorios, paso a buscar el archivo manifest.json y obtener su contenido
    const manifests = yield shared_1.getManifestsContent(files);
    if (manifests.length) {
        shared_1.logger.info("Update manifest information");
        const content = yield shared_1.getManifestContent(directory);
        if (content) {
            updateManifestInfo(content, vendor);
        }
        return true;
    }
    else {
        return false;
    }
});
const updateManifestInfo = (manifest, vendor) => __awaiter(void 0, void 0, void 0, function* () {
    manifest.vendor = vendor;
    let manifestCopy = Object.assign({}, manifest);
    delete manifestCopy.path;
    yield writeFile(manifest.path, JSON.stringify(manifestCopy, null, 4));
});
const writeFile = (path, string) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield fs_1.writeFileSync(path + "/manifest.json", string);
        shared_1.logger.info("manifest file update.");
    }
    catch (error) {
        shared_1.logger.error(error);
    }
});
